import duckdb

class DuckDBManager:
    def __init__(self, db_name=':memory:'):
        """Initialize the DuckDB connection."""
        self.connection = duckdb.connect(database=db_name)

    def insert_data(self, table_name, data):
        """
        Insert a list of dictionaries into a specified DuckDB table.

        Parameters:
        - table_name (str): The name of the table to insert data into.
        - data (list): A list of dictionaries containing the data to insert.
        """
        # Create a DataFrame from the list of dictionaries
        df = duckdb.from_df(data)
        
        # Create the table and insert the data
        self.connection.execute(f"CREATE TABLE IF NOT EXISTS {table_name} AS SELECT * FROM df")
        self.connection.execute(f"INSERT INTO {table_name} SELECT * FROM df")

    def execute_query(self, query):
        """
        Execute an arbitrary SQL query against DuckDB.

        Parameters:
        - query (str): The SQL query to execute.
        
        Returns:
        - result: The result of the query execution.
        """
        result = self.connection.execute(query).fetchall()
        return result

    def close(self):
        """Close the DuckDB connection."""
        self.connection.close()


import setuptools

with open("README.md") as file:
    read_me_description = file.read()

setuptools.setup(
    name="executor-invest-helper",
    version="0.1.4",
    author="Invest Guru",
    author_email="example@gmail.com",
    description="Database Executor for Invest Helper",
    long_description=read_me_description,
    long_description_content_type="text/markdown",
    url="https://github.com/sazonovvladimir/invest_helper_bot",
    packages=['executor'],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.5',
)